﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.Windows.Controls;

namespace SilverlightDocking
{
    public class ExampleViewModel : ViewModelBase
    {
        private Random r = new Random();
        private List<List<TemperatureData>> _data;

        public ExampleViewModel()
        {
            this.FillSampleChartData();
        }

        public List<List<TemperatureData>> Data 
        {
            get
            {
                return this._data;
            }
            set
            {
                if (this._data != value)
                {
                    this._data = value;
                    this.OnPropertyChanged("Data");
                }
            }
        }

        private void FillSampleChartData()
        {
            List<TemperatureData> temperatureData = new List<TemperatureData>();
            DateTime baseDate = new DateTime(2000, 1, 1);

            for (int year = 0; year < 12; year++)
            {
                for (int day = 0; day < 365; day++)
                {
                    for (int hour = 0; hour < 24; hour++)
                    {
                        TemperatureData tempData = new TemperatureData();
                        tempData.Temperature = TranslateTemperatureValue(CalculateBaseTemperatureValue(day));
                        tempData.Date = baseDate.AddYears(year).AddDays(day).AddHours(hour);
                        temperatureData.Add(tempData);
                    }
                }
            }

            this.Data = new List<List<TemperatureData>>() { temperatureData, temperatureData, temperatureData, temperatureData, temperatureData };
        }

        private static double CalculateBaseTemperatureValue(int day)
        {
            return Math.Sin(day / 365d * 2 * Math.PI - Math.PI / 2);
        }

        private double TranslateTemperatureValue(double baseTemperatureValue)
        {
            return (baseTemperatureValue + 1) * 20 - 10 + r.Next(-5, 5);
        }
    }
}
